@@ -70,10 +70,12 @@ char *strstr ();
 #    if HAVE_NCURSES_H
 #     include <ncurses.h>
 #    endif
+#   endif
+#   if HAVE_TERM_H
+#    include <term.h>
+#   endif
 #  endif
 # endif
-const char *tgetstr ();
-# endif
 #endif
 
 #include <setjmp.h>
